==> migrate_wizard-1.0.21-alpha1.tar.gz: migrate_wizard/src/Form/BaseFormFields.php <==
<?php


namespace Drupal\migrate_wizard\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\migrate_wizard\MWManageDataService;
use Drupal\migrate_wizard\MWManageFormService;

/**
 * @property array|mixed|null currentConfig
 * @property string[] checkboxes
 * @property mixed|string destinyType
 * @property MWManageFormService manageFormService
 * @property array fieldsOriginBundle
 * @property MWManageDataService mwManageDataService
 * @property  array arrayFieldsOriginBundle
 * @property  array entityFieldsDestiny*
 * @property array[]|mixed $langCodes
 * @property $i18nMode
 */
abstract class BaseFormFields extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, string $origin_bundle = NULL) {

    $form['origin_bundle'] = [
      '#type' => 'hidden',
      '#value' => $origin_bundle,
    ];
    if($this->originType != 'user' && $this->originType != 'field_collection_item' && $this->originType != 'paragraphs_item'){
      $this->destinyType = '';
      if ($this->currentConfig && isset($this->currentConfig['destiny_type'])) {
        $this->destinyType = $this->currentConfig['destiny_type'];
      }
    }
    $form['destiny_type'] = [
      '#type' => 'hidden',
      '#value' => $this->destinyType,
      '#prefix' => '<div class="destiny_type_box">',
      '#suffix' => '</div>',
    ];

    $this->manageFormService->buildCheckboxes($form, $this->checkboxes);
    if($this->currentConfig == NULL || $this->destinyType != 'user'){
      $this->manageFormService->buildLangcodes($form, $this->langCodes, $this->i18nMode);
    }

    $options_source_origin_type_node = $this->manageFormService->getOriginNodeTypes();
    $options_source_origin_type_vocabulary = $this->manageFormService->getOriginVocavularyTypes();
    $both_options_source = ['none' => 'Select dependency'] + ['Content types' => $options_source_origin_type_node, 'Vocabularies' => $options_source_origin_type_vocabulary];

    $current_source_type_value = 'none';
    $current_source_type_vocabulary_value = 'none';
    $current_source_type_paragraph_value = 'none';

    $form_state->disableCache(); // TODO investigate this, build ajaxcallback on service get error without this line
    if($this->destinyType != 'user' && $this->originType != 'field_collection_item' && $this->originType != 'paragraphs_item'){
      $this->manageFormService->buildSourceTypesForm($form, $current_source_type_value, $current_source_type_vocabulary_value, $current_source_type_paragraph_value);
    }elseif($this->originType != 'field_collection_item' && $this->originType != 'paragraphs_item'){
      $form['source_type'] = [
        '#type' => 'hidden',
        '#value' => 'user',
      ];
    }elseif($this->originType == 'field_collection_item' || $this->originType == 'paragraphs_item'){
      $this->manageFormService->buildSourceTypesParagraphsForm($form, $current_source_type_value);
    }
    if($this->originType != 'field_collection_item'){
      $default_value = '';
      if (is_array($this->currentConfig) && isset($this->currentConfig['import_only_ids'])) {
        $default_value = $this->currentConfig['import_only_ids'];
      }
      $form['import_only_ids'] = [
        '#type' => 'textfield',
        '#title' => t('import only this ids'),
        '#description' => t('write here the origin ids to import, separated by comma'),
        '#pattern' => '\d+(,\d+)*',
        '#size' => '20',
        '#default_value' => $default_value,
      ];

      $default_value = '';
      if (is_array($this->currentConfig) && isset($this->currentConfig['limit_import'])) {
        $default_value = $this->currentConfig['limit_import'];
      }
      $form['limit_import'] = [
        '#type' => 'number',
        '#title' => t('limit import'),
        '#description' => t('write here the limit of items to import'),
        '#size' => '20',
        '#default_value' => $default_value,
      ];
    }

    $form['source_destiny_fields'] = [
      '#type' => 'fieldset',
      '#title' => t('Fields'),
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
      '#prefix' => '<div class="source-destiny-fields-wrapper" id="source-destiny-fields-wrapper">',
      '#suffix' => '</div>',
    ];

    $current_config_node = [];
    if (is_array($this->currentConfig)) {
      $current_config_node = reset($this->currentConfig);
    }
    $generic_current_source_type_value = $current_source_type_value != 'none' ? $current_source_type_value : $current_source_type_vocabulary_value;

    $current_options_source_destiny_fields_array['fields_array'] = ['none' => 'Select a field'];
    $current_options_source_destiny_fields_array['fields_array_destiny_type'] = [];

    $this->destinyType != 'user' ?: $generic_current_source_type_value = $this->destinyType;
    if($this->destinyType != NULL && $generic_current_source_type_value != 'none'){
      $current_options_source_destiny_fields_array = $this->manageFormService->getDestinyFieldsByBundle($this->destinyType, $generic_current_source_type_value);
    }
    if($this->originType != 'field_collection_item'){
      $this->manageFormService->buildWorkbenchAccessForm($form, $current_options_source_destiny_fields_array, $current_config_node, $both_options_source);
    }
    $form['source_destiny_fields_type'] = [
      '#type' => 'fieldset',
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
      '#attributes' => ['style' => 'display: none;'],
      '#prefix' => '<div class="source-destiny-fields-type-wrapper" id="source-destiny-fields-type-wrapper">',
      '#suffix' => '</div>',
    ];

    foreach ($current_options_source_destiny_fields_array['fields_array_destiny_type'] as $key => $current_options_source_destiny_field_type) {
      $form['source_destiny_fields_type'][$key . '_type'] = [
        '#type' => 'hidden',
        '#name' => $key . '_type',
        '#value' => $current_options_source_destiny_field_type,
      ];
    }

    $this->manageFormService->buildFieldsForm($form, $current_options_source_destiny_fields_array['fields_array'], $generic_current_source_type_value, $both_options_source, $current_config_node, $this->fieldsOriginBundle);

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];
    $form['#attached']['library'][] = 'migrate_wizard/form';
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {}

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void
  {
    $this->manageFormService->submitForm($form, $form_state);
  }

  public function getTitle($type = null): \Drupal\Core\StringTranslation\TranslatableMarkup
  {
    $current_path = \Drupal::service('path.current')->getPath();
    $path = explode('/', $current_path);
    $path = end($path);
    return $this->t('Manage fields '.$this->mwManageDataService->getOriginBundleTitle($path, $type));
  }
}

==> migrate_wizard-2.0.2-alpha1.tar.gz: migrate_wizard/src/Form/BaseFormFields.php <==
<?php


namespace Drupal\migrate_wizard\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\migrate_wizard\MWManageDataService;
use Drupal\migrate_wizard\MWManageFormService;

/**
 * @property array|mixed|null currentConfig
 * @property string[] checkboxes
 * @property mixed|string destinyType
 * @property MWManageFormService manageFormService
 * @property array fieldsOriginBundle
 * @property MWManageDataService mwManageDataService
 * @property  array arrayFieldsOriginBundle
 * @property  array entityFieldsDestiny*
 * @property array[]|mixed $langCodes
 * @property $i18nMode
 */
abstract class BaseFormFields extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $origin_entity = NULL) {

    $form['origin_bundle'] = [
      '#type' => 'hidden',
      '#value' => $origin_entity->id_origin,
    ];
    if($this->originType != 'user' && $this->originType != 'field_collection_item' && $this->originType != 'paragraphs_item'){
      $this->destinyType = '';
      if ($this->currentConfig && isset($this->currentConfig['destiny_type'])) {
        $this->destinyType = $this->currentConfig['destiny_type'];
      }
    }
    $form['destiny_type'] = [
      '#type' => 'hidden',
      '#value' => $this->destinyType,
      '#prefix' => '<div class="destiny_type_box">',
      '#suffix' => '</div>',
    ];

    $this->manageFormService->buildCheckboxes($form, $this->checkboxes);
    if($this->currentConfig == NULL || $this->destinyType != 'user'){
      $this->manageFormService->buildLangcodes($form, $this->langCodes, $this->i18nMode);
    }

    $options_source_origin_type_node = $this->manageFormService->getOriginNodeTypes();
    $options_source_origin_type_vocabulary = $this->manageFormService->getOriginVocavularyTypes();
    $both_options_source = ['none' => 'Select dependency'] + ['Content types' => $options_source_origin_type_node, 'Vocabularies' => $options_source_origin_type_vocabulary];

    $current_source_type_value = 'none';
    $current_source_type_vocabulary_value = 'none';
    $current_source_type_paragraph_value = 'none';

    $form_state->disableCache(); // TODO investigate this, build ajaxcallback on service get error without this line
    if($this->destinyType != 'user' && $this->originType != 'field_collection_item' && $this->originType != 'paragraphs_item'){
      $this->manageFormService->buildSourceTypesForm($form, $current_source_type_value, $current_source_type_vocabulary_value, $current_source_type_paragraph_value);
    }elseif($this->originType != 'field_collection_item' && $this->originType != 'paragraphs_item'){
      $form['source_type'] = [
        '#type' => 'hidden',
        '#value' => 'user',
      ];
    }elseif($this->originType == 'field_collection_item' || $this->originType == 'paragraphs_item'){
      $this->manageFormService->buildSourceTypesParagraphsForm($form, $current_source_type_value);
    }
    if($this->originType != 'field_collection_item'){
      $default_value = '';
      if (is_array($this->currentConfig) && isset($this->currentConfig['import_only_ids'])) {
        $default_value = $this->currentConfig['import_only_ids'];
      }
      $form['import_only_ids'] = [
        '#type' => 'textfield',
        '#title' => t('import only this ids'),
        '#description' => t('write here the origin ids to import, separated by comma'),
        '#pattern' => '\d+(,\d+)*',
        '#size' => '20',
        '#default_value' => $default_value,
      ];

      $default_value = '';
      if (is_array($this->currentConfig) && isset($this->currentConfig['limit_import'])) {
        $default_value = $this->currentConfig['limit_import'];
      }
      $form['limit_import'] = [
        '#type' => 'number',
        '#title' => t('limit import'),
        '#description' => t('write here the limit of items to import'),
        '#size' => '20',
        '#default_value' => $default_value,
      ];
    }

    $form['source_destiny_fields'] = [
      '#type' => 'fieldset',
      '#title' => t('Fields'),
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
      '#prefix' => '<div class="source-destiny-fields-wrapper" id="source-destiny-fields-wrapper">',
      '#suffix' => '</div>',
    ];

    $current_config_node = [];
    if (is_array($this->currentConfig)) {
      $current_config_node = reset($this->currentConfig);
    }
    $generic_current_source_type_value = $current_source_type_value != 'none' ? $current_source_type_value : $current_source_type_vocabulary_value;

    $current_options_source_destiny_fields_array['fields_array'] = ['none' => 'Select a field'];
    $current_options_source_destiny_fields_array['fields_array_destiny_type'] = [];

    $this->destinyType != 'user' ?: $generic_current_source_type_value = $this->destinyType;
    if($this->destinyType != NULL && $generic_current_source_type_value != 'none'){
      $current_options_source_destiny_fields_array = $this->manageFormService->getDestinyFieldsByBundle($this->destinyType, $generic_current_source_type_value);
    }
    if($this->originType != 'field_collection_item'){
      $this->manageFormService->buildWorkbenchAccessForm($form, $current_options_source_destiny_fields_array, $current_config_node, $both_options_source);
    }
    $form['source_destiny_fields_type'] = [
      '#type' => 'fieldset',
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
      '#attributes' => ['style' => 'display: none;'],
      '#prefix' => '<div class="source-destiny-fields-type-wrapper" id="source-destiny-fields-type-wrapper">',
      '#suffix' => '</div>',
    ];

    foreach ($current_options_source_destiny_fields_array['fields_array_destiny_type'] as $key => $current_options_source_destiny_field_type) {
      $form['source_destiny_fields_type'][$key . '_type'] = [
        '#type' => 'hidden',
        '#name' => $key . '_type',
        '#value' => $current_options_source_destiny_field_type,
      ];
    }

    $this->manageFormService->buildFieldsForm($form, $current_options_source_destiny_fields_array['fields_array'], $generic_current_source_type_value, $both_options_source, $current_config_node, $this->fieldsOriginBundle);

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];
    $form['#attached']['library'][] = 'migrate_wizard/form';
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {}

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void
  {
    $this->manageFormService->submitForm($form, $form_state);
  }

  public function getTitle($type = null): \Drupal\Core\StringTranslation\TranslatableMarkup
  {
    $current_path = \Drupal::service('path.current')->getPath();
    $path = explode('/', $current_path);
    $path = end($path);
    return $this->t('Manage fields '.$this->mwManageDataService->getOriginBundleTitle($path, $type));
  }
}
